@@ -6,10 +6,14 @@
 
 #include "ui/base/class_property.h"
 
+DEFINE_EXPORTED_UI_CLASS_PROPERTY_TYPE(AX_EXPORT, AXRole)
+
 namespace ui {
 
 DEFINE_UI_CLASS_PROPERTY_KEY(AXTreeIDRegistry::AXTreeID,
                              kChildAXTreeID,
                              AXTreeIDRegistry::kNoAXTreeID);
 
+DEFINE_UI_CLASS_PROPERTY_KEY(AXRole, kAXRoleOverride, ui::AX_ROLE_NONE);
+
 }  // namespace ui
