@@ -2,18 +2,14 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-// MSVC++ requires this to be set before any other includes to get M_PI.
-#define _USE_MATH_DEFINES
-
 #include "ui/gfx/transform.h"
 
-#include <cmath>
-
 #include "base/logging.h"
 #include "base/strings/stringprintf.h"
+#include "ui/gfx/geometry/angle_conversions.h"
 #include "ui/gfx/geometry/box_f.h"
-#include "ui/gfx/geometry/point.h"
 #include "ui/gfx/geometry/point3_f.h"
+#include "ui/gfx/geometry/point_conversions.h"
 #include "ui/gfx/geometry/quaternion.h"
 #include "ui/gfx/geometry/rect.h"
 #include "ui/gfx/geometry/safe_integer_conversions.h"
@@ -28,8 +24,7 @@ namespace {
 const SkMScalar kEpsilon = std::numeric_limits<float>::epsilon();
 
 SkMScalar TanDegrees(double degrees) {
-  double radians = degrees * M_PI / 180;
-  return SkDoubleToMScalar(std::tan(radians));
+  return SkDoubleToMScalar(std::tan(gfx::DegToRad(degrees)));
 }
 
 inline bool ApproximatelyZero(SkMScalar x, SkMScalar tolerance) {
@@ -40,12 +35,6 @@ inline bool ApproximatelyOne(SkMScalar x, SkMScalar tolerance) {
   return std::abs(x - SkDoubleToMScalar(1.0)) <= tolerance;
 }
 
-static float Round(float f) {
-  if (f == 0.f)
-    return f;
-  return (f > 0.f) ? std::floor(f + 0.5f) : std::ceil(f - 0.5f);
-}
-
 }  // namespace
 
 Transform::Transform(SkMScalar col1row1,
@@ -121,7 +110,7 @@ Transform::Transform(const Quaternion& q)
 }
 
 void Transform::RotateAboutXAxis(double degrees) {
-  double radians = degrees * M_PI / 180;
+  double radians = gfx::DegToRad(degrees);
   SkMScalar cosTheta = SkDoubleToMScalar(std::cos(radians));
   SkMScalar sinTheta = SkDoubleToMScalar(std::sin(radians));
   if (matrix_.isIdentity()) {
@@ -138,7 +127,7 @@ void Transform::RotateAboutXAxis(double degrees) {
 }
 
 void Transform::RotateAboutYAxis(double degrees) {
-  double radians = degrees * M_PI / 180;
+  double radians = gfx::DegToRad(degrees);
   SkMScalar cosTheta = SkDoubleToMScalar(std::cos(radians));
   SkMScalar sinTheta = SkDoubleToMScalar(std::sin(radians));
   if (matrix_.isIdentity()) {
@@ -157,7 +146,7 @@ void Transform::RotateAboutYAxis(double degrees) {
 }
 
 void Transform::RotateAboutZAxis(double degrees) {
-  double radians = degrees * M_PI / 180;
+  double radians = gfx::DegToRad(degrees);
   SkMScalar cosTheta = SkDoubleToMScalar(std::cos(radians));
   SkMScalar sinTheta = SkDoubleToMScalar(std::sin(radians));
   if (matrix_.isIdentity()) {
@@ -433,6 +422,11 @@ void Transform::TransformPoint(Point* point) const {
   TransformPointInternal(matrix_, point);
 }
 
+void Transform::TransformPoint(PointF* point) const {
+  DCHECK(point);
+  TransformPointInternal(matrix_, point);
+}
+
 void Transform::TransformPoint(Point3F* point) const {
   DCHECK(point);
   TransformPointInternal(matrix_, point);
@@ -533,8 +527,10 @@ bool Transform::Blend(const Transform& from, double progress) {
 }
 
 void Transform::RoundTranslationComponents() {
-  matrix_.set(0, 3, Round(matrix_.get(0, 3)));
-  matrix_.set(1, 3, Round(matrix_.get(1, 3)));
+  // TODO(pkasting): Use SkMScalarRound() when
+  // https://bugs.chromium.org/p/skia/issues/detail?id=6852 is fixed.
+  matrix_.set(0, 3, std::round(matrix_.get(0, 3)));
+  matrix_.set(1, 3, std::round(matrix_.get(1, 3)));
 }
 
 void Transform::TransformPointInternal(const SkMatrix44& xform,
@@ -572,16 +568,23 @@ void Transform::TransformVectorInternal(const SkMatrix44& xform,
 }
 
 void Transform::TransformPointInternal(const SkMatrix44& xform,
-                                       Point* point) const {
+                                       PointF* point) const {
   if (xform.isIdentity())
     return;
 
-  SkMScalar p[4] = {SkIntToMScalar(point->x()), SkIntToMScalar(point->y()),
-                    0, 1};
+  SkMScalar p[4] = {SkIntToMScalar(point->x()), SkIntToMScalar(point->y()), 0,
+                    1};
 
   xform.mapMScalars(p);
 
-  point->SetPoint(ToRoundedInt(p[0]), ToRoundedInt(p[1]));
+  point->SetPoint(p[0], p[1]);
+}
+
+void Transform::TransformPointInternal(const SkMatrix44& xform,
+                                       Point* point) const {
+  PointF point_float(*point);
+  TransformPointInternal(xform, &point_float);
+  *point = ToRoundedPoint(point_float);
 }
 
 bool Transform::ApproximatelyEqual(const gfx::Transform& transform) const {
